@@ -12,8 +12,12 @@ function(definition=NULL, call=sys.call(sys.parent(1)), expand.dots = TRUE)
 	call <- .Internal(match.call(definition, call, expand.dots))
 	#given args:
 	ans <- as.list(call)
+	# ans1 <- ans[[1]]
+	# ans <- lapply(ans[-1], eval, envir = sys.frame(sys.parent(2)))
+	# ans <- c(ans1, ans)
+		
 	#possible args:
-	frmls <- formals(deparse(ans[[1]]))
+	frmls <- formals(safeDeparse(ans[[1]]))
 	#remove formal args with no presets:
 	frmls <- frmls[!sapply(frmls, is.symbol)]
 	
